==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/qashctl/src/mwdg/mixer_hctl_int_proxy_slider.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/pad_proxy_slider.hpp"
#include "wdg/uint_mapper.hpp"
#include <QObject>

// Forward declaration
namespace QSnd
{
class Mixer_HCTL_Elem;
}

namespace MWdg
{

/// @brief Mixer_HCTL_Int_Proxy_Slider
///
class Mixer_HCTL_Int_Proxy_Slider : public ::Wdg::Pad_Proxy_Slider
{
  Q_OBJECT

  // Public methods
  public:
  // -- Construction

  Mixer_HCTL_Int_Proxy_Slider ( ::QSnd::Mixer_HCTL_Elem * elem_n,
                                unsigned int elem_idx_n );

  ~Mixer_HCTL_Int_Proxy_Slider ();

  // -- Snd element

  ::QSnd::Mixer_HCTL_Elem *
  snd_elem () const
  {
    return _snd_elem;
  }

  unsigned int
  elem_idx () const
  {
    return _elem_idx;
  }

  // -- Joined

  bool
  is_joined () const
  {
    return _is_joined;
  }

  void
  set_joined ( bool flag_n );

  bool
  joined_by_key () const;

  // -- Integer value

  long
  integer_min () const;

  long
  integer_max () const;

  long
  integer_value () const
  {
    return _integer_value;
  }

  unsigned long
  integer_to_index ( long integer_n ) const
  {
    unsigned long res = ::Wdg::integer_distance ( integer_min (), integer_n );
    return res;
  }

  long
  index_to_integer ( unsigned long index_n ) const
  {
    long res = integer_min ();
    res += index_n;
    return res;
  }

  // -- Signals

  Q_SIGNAL
  void
  sig_integer_value_changed ( long value_n );

  Q_SIGNAL
  void
  sig_integer_value_changed ( int value_n );

  // -- Public slots

  Q_SLOT
  void
  set_integer_value ( long value_n );

  Q_SLOT
  void
  set_integer_value ( int value_n );

  Q_SLOT
  void
  update_value_from_source ();

  // Protected methods
  protected:
  void
  integer_value_changed ();

  void
  slider_index_changed ();

  // Private attributes
  private:
  ::QSnd::Mixer_HCTL_Elem * _snd_elem;
  unsigned int _elem_idx;

  long _integer_value;
  bool _is_joined;
  bool _updating_state;
};

} // namespace MWdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/qashctl/src/mwdg/mixer_hctl_int_proxy_slider.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/pad_proxy_slider.hpp"
#include "wdg/uint_mapper.hpp"
#include <QObject>

// Forward declaration
namespace QSnd::HCtl
{
class Elem;
}

namespace MWdg
{

/// @brief Mixer_HCTL_Int_Proxy_Slider
///
class Mixer_HCTL_Int_Proxy_Slider : public Wdg::Pad_Proxy_Slider
{
  Q_OBJECT

  public:
  // -- Construction

  Mixer_HCTL_Int_Proxy_Slider ( QSnd::HCtl::Elem * elem_n,
                                unsigned int elem_idx_n );

  ~Mixer_HCTL_Int_Proxy_Slider ();

  // -- Snd element

  QSnd::HCtl::Elem *
  snd_elem () const
  {
    return _snd_elem;
  }

  unsigned int
  elem_idx () const
  {
    return _elem_idx;
  }

  // -- Joined

  bool
  is_joined () const
  {
    return _is_joined;
  }

  void
  set_joined ( bool flag_n );

  bool
  joined_by_key () const;

  // -- Integer value

  long
  integer_min () const;

  long
  integer_max () const;

  long
  integer_value () const
  {
    return _integer_value;
  }

  unsigned long
  integer_to_index ( long integer_n ) const
  {
    unsigned long res = Wdg::integer_distance ( integer_min (), integer_n );
    return res;
  }

  long
  index_to_integer ( unsigned long index_n ) const
  {
    long res = integer_min ();
    res += index_n;
    return res;
  }

  // -- Signals

  Q_SIGNAL
  void
  sig_integer_value_changed ( long value_n );

  Q_SIGNAL
  void
  sig_integer_value_changed ( int value_n );

  // -- Public slots

  Q_SLOT
  void
  set_integer_value ( long value_n );

  Q_SLOT
  void
  set_integer_value ( int value_n );

  Q_SLOT
  void
  update_value_from_source ();

  protected:
  // -- Protected methods

  void
  integer_value_changed ();

  void
  slider_index_changed ();

  private:
  // -- Attributes
  QSnd::HCtl::Elem * _snd_elem;
  unsigned int _elem_idx;

  long _integer_value;
  bool _is_joined;
  bool _updating_state;
};

} // namespace MWdg
